summaryrefslogtreecommitdiff
path: root/sw/source
diff options
context:
space:
mode:
authorOliver Bolte <obo@openoffice.org>2004-08-12 09:14:44 +0000
committerOliver Bolte <obo@openoffice.org>2004-08-12 09:14:44 +0000
commit8277d6794358bcb80314524bc8298a28443664bc (patch)
tree9cfeffad7dc558592493994847b27c018a4fac3b /sw/source
parentda4dfa832952a57d812db3d955607e3ca35851be (diff)
INTEGRATION: CWS jmf2 (1.19.16); FILE MERGED
2004/07/23 15:13:00 ka 1.19.16.1: #i3316#: support for media objects
Diffstat (limited to 'sw/source')
-rw-r--r--sw/source/ui/inc/wrtsh.hxx7
1 files changed, 4 insertions, 3 deletions
diff --git a/sw/source/ui/inc/wrtsh.hxx b/sw/source/ui/inc/wrtsh.hxx
index 59050f3999ae..5ea9af603730 100644
--- a/sw/source/ui/inc/wrtsh.hxx
+++ b/sw/source/ui/inc/wrtsh.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: wrtsh.hxx,v $
*
- * $Revision: 1.20 $
+ * $Revision: 1.21 $
*
- * last change: $Author: kz $ $Date: 2004-08-02 13:06:59 $
+ * last change: $Author: obo $ $Date: 2004-08-12 10:14:44 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -133,7 +133,8 @@ public:
SEL_DRW_TXT = 0x0400, // Draw-Textobjekte im Editmode
SEL_BEZ = 0x0800, // Bezierobjekte editieren
SEL_DRW_FORM = 0x1000, // Zeichenobjekte: DB-Forms
- FOC_FRM_CTRL = 0x2000 // a form control is focused. Neither set nor evaluated by the SwWrtShell itself, only by it's clients.
+ FOC_FRM_CTRL = 0x2000, // a form control is focused. Neither set nor evaluated by the SwWrtShell itself, only by it's clients.
+ SEL_MEDIA = 0x4000 // Media object
};
int GetSelectionType() const;